@@ -1,8 +1,8 @@
 """JQuery-Ajax Autocomplete fields for Django Forms"""
-__version__ = "1.2.4"
+__version__ = "1.2.5"
 __author__ = "crucialfelix"
 __contact__ = "crucialfelix@gmail.com"
-__homepage__ = "http://code.google.com/p/django-ajax-selects/"
+__homepage__ = "https://github.com/crucialfelix/django-ajax-selects/"
 
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured, PermissionDenied
@@ -16,12 +16,13 @@ from django.utils.translation import ugettext_lazy as _, ugettext
 class LookupChannel(object):
 
     """Subclass this, setting model and overiding the methods below to taste"""
-    
+
     model = None
+    plugin_options = {}
     min_length = 1
-    
+
     def get_query(self,q,request):
-        """ return a query set searching for the query string q 
+        """ return a query set searching for the query string q
             either implement this method yourself or set the search_field
             in the LookupChannel class definition
         """
@@ -51,7 +52,7 @@ class LookupChannel(object):
         return [things[aid] for aid in ids if things.has_key(aid)]
 
     def can_add(self,user,argmodel):
-        """ Check if the user has permission to add 
+        """ Check if the user has permission to add
             one of these models. This enables the green popup +
             Default is the standard django permission check
         """
@@ -71,13 +72,13 @@ class LookupChannel(object):
 
 def make_ajax_form(model,fieldlist,superclass=ModelForm,show_help_text=False,**kwargs):
     """ Creates a ModelForm subclass with autocomplete fields
-            
+
         usage:
             class YourModelAdmin(Admin):
                 ...
                 form = make_ajax_form(YourModel,{'contacts':'contact','author':'contact'})
 
-        where 
+        where
             'contacts' is a ManyToManyField specifying to use the lookup channel 'contact'
         and
             'author' is a ForeignKeyField specifying here to also use the lookup channel 'contact'
@@ -85,9 +86,9 @@ def make_ajax_form(model,fieldlist,superclass=ModelForm,show_help_text=False,**k
     # will support previous arg name for several versions before deprecating
     if 'show_m2m_help' in kwargs:
         show_help_text = kwargs.pop('show_m2m_help')
-        
+
     class TheForm(superclass):
-        
+
         class Meta:
             pass
         setattr(Meta, 'model', model)
@@ -106,12 +107,12 @@ def make_ajax_field(model,model_fieldname,channel,show_help_text = False,**kwarg
     """ Makes a single autocomplete field for use in a Form
 
         optional args:
-            help_text - default is the model db field's help_text. 
+            help_text - default is the model db field's help_text.
                 None will disable all help text
             label     - default is the model db field's verbose name
             required  - default is the model db field's (not) blank
-        
-            show_help_text - 
+
+            show_help_text -
                 Django will show help text below the widget, but not for ManyToMany inside of admin inlines
                 This setting will show the help text inside the widget itself.
     """
@@ -124,46 +125,28 @@ def make_ajax_field(model,model_fieldname,channel,show_help_text = False,**kwarg
                                    AutoCompleteSelectField
 
     field = model._meta.get_field(model_fieldname)
-    if kwargs.has_key('label'):
-        label = kwargs.pop('label')
-    else:
-        label = _(capfirst(unicode(field.verbose_name)))
+    if not kwargs.has_key('label'):
+        kwargs['label'] = _(capfirst(unicode(field.verbose_name)))
 
-    if kwargs.has_key('help_text'):
-        help_text = kwargs.pop('help_text')
-    else:
-        if isinstance(field.help_text,basestring) and field.help_text:
-            help_text = _(field.help_text)
-        else:
-            help_text = field.help_text
-    if kwargs.has_key('required'):
-        required = kwargs.pop('required')
-    else:
-        required = not field.blank
+    if not kwargs.has_key('help_text') and field.help_text:
+        kwargs['help_text'] = field.help_text
+    if not kwargs.has_key('required'):
+        kwargs['required'] = not field.blank
 
     kwargs['show_help_text'] = show_help_text
     if isinstance(field,ManyToManyField):
         f = AutoCompleteSelectMultipleField(
             channel,
-            required=required,
-            help_text=help_text,
-            label=label,
             **kwargs
             )
     elif isinstance(field,ForeignKey):
         f = AutoCompleteSelectField(
             channel,
-            required=required,
-            help_text=help_text,
-            label=label,
             **kwargs
             )
     else:
         f = AutoCompleteField(
             channel,
-            required=required,
-            help_text=help_text,
-            label=label,
             **kwargs
             )
     return f
@@ -197,11 +180,11 @@ def get_lookup(channel):
                     lambda self,obj: unicode(obj)))
         if not hasattr(lookup_class,'format_item_display'):
             setattr(lookup_class, 'format_item_display',
-                getattr(lookup_class,'format_item', 
+                getattr(lookup_class,'format_item',
                     lambda self,obj: unicode(obj)))
         if not hasattr(lookup_class,'get_result'):
             setattr(lookup_class, 'get_result',
-                getattr(lookup_class,'format_result', 
+                getattr(lookup_class,'format_result',
                     lambda self,obj: unicode(obj)))
 
         return lookup_class()
@@ -210,17 +193,17 @@ def get_lookup(channel):
 def make_channel(app_model,arg_search_field):
     """ used in get_lookup
             app_model :   app_name.model_name
-            search_field :  the field to search against and to display in search results 
+            search_field :  the field to search against and to display in search results
     """
     from django.db import models
     app_label, model_name = app_model.split(".")
     themodel = models.get_model(app_label, model_name)
-    
+
     class MadeLookupChannel(LookupChannel):
-        
+
         model = themodel
         search_field = arg_search_field
-        
+
     return MadeLookupChannel()
 
 
